==> ixnetwork_restpy-1.0.54-py2.py3-none-any.whl: uhd_restpy/testplatform/sessions/ixnetwork/vport/protocols/periodicoamlmlearnedinfo_ee2b776d335186db7b509aa54dc286c1.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
from uhd_restpy.base import Base
from uhd_restpy.files import Files


class PeriodicOamLmLearnedInfo(Base):
    """
    The PeriodicOamLmLearnedInfo class encapsulates a list of periodicOamLmLearnedInfo resources that are managed by the system.
    A list of resources can be retrieved from the server using the PeriodicOamLmLearnedInfo.find() method.
    """

    __slots__ = ()
    _SDM_NAME = 'periodicOamLmLearnedInfo'
    _SDM_ATT_MAP = {
        'AvgFarEndLoss': 'avgFarEndLoss',
        'AvgNearEndLoss': 'avgNearEndLoss',
        'BVlan': 'bVlan',
        'CVlan': 'cVlan',
        'CcmReceivedCount': 'ccmReceivedCount',
        'CcmSentCount': 'ccmSentCount',
        'CurrentFarEndLoss': 'currentFarEndLoss',
        'CurrentFarEndLossRatio': 'currentFarEndLossRatio',
        'CurrentNearEndLoss': 'currentNearEndLoss',
        'CurrentNearEndLossRatio': 'currentNearEndLossRatio',
        'DestinationMacAddress': 'destinationMacAddress',
        'LmmSentCount': 'lmmSentCount',
        'MaxFarEndLoss': 'maxFarEndLoss',
        'MaxFarEndLossRatio': 'maxFarEndLossRatio',
        'MaxNearEndLoss': 'maxNearEndLoss',
        'MaxNearEndLossRatio': 'maxNearEndLossRatio',
        'MdLevel': 'mdLevel',
        'MinFarEndLoss': 'minFarEndLoss',
        'MinFarEndLossRatio': 'minFarEndLossRatio',
        'MinNearEndLoss': 'minNearEndLoss',
        'MinNearEndLossRatio': 'minNearEndLossRatio',
        'NoReplyCount': 'noReplyCount',
        'SVlan': 'sVlan',
        'SourceMacAddress': 'sourceMacAddress',
        'SourceMepId': 'sourceMepId',
    }

    def __init__(self, parent):
        super(PeriodicOamLmLearnedInfo, self).__init__(parent)

    @property
    def AvgFarEndLoss(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['AvgFarEndLoss'])

    @property
    def AvgNearEndLoss(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['AvgNearEndLoss'])

    @property
    def BVlan(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['BVlan'])

    @property
    def CVlan(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['CVlan'])

    @property
    def CcmReceivedCount(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['CcmReceivedCount'])

    @property
    def CcmSentCount(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['CcmSentCount'])

    @property
    def CurrentFarEndLoss(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentFarEndLoss'])

    @property
    def CurrentFarEndLossRatio(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentFarEndLossRatio'])

    @property
    def CurrentNearEndLoss(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentNearEndLoss'])

    @property
    def CurrentNearEndLossRatio(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentNearEndLossRatio'])

    @property
    def DestinationMacAddress(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['DestinationMacAddress'])

    @property
    def LmmSentCount(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['LmmSentCount'])

    @property
    def MaxFarEndLoss(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxFarEndLoss'])

    @property
    def MaxFarEndLossRatio(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxFarEndLossRatio'])

    @property
    def MaxNearEndLoss(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxNearEndLoss'])

    @property
    def MaxNearEndLossRatio(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxNearEndLossRatio'])

    @property
    def MdLevel(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MdLevel'])

    @property
    def MinFarEndLoss(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinFarEndLoss'])

    @property
    def MinFarEndLossRatio(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinFarEndLossRatio'])

    @property
    def MinNearEndLoss(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinNearEndLoss'])

    @property
    def MinNearEndLossRatio(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinNearEndLossRatio'])

    @property
    def NoReplyCount(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['NoReplyCount'])

    @property
    def SVlan(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['SVlan'])

    @property
    def SourceMacAddress(self):
        """
        Returns
        -------
        - str: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['SourceMacAddress'])

    @property
    def SourceMepId(self):
        """
        Returns
        -------
        - number: 
        """
        return self._get_attribute(self._SDM_ATT_MAP['SourceMepId'])

    def find(self, AvgFarEndLoss=None, AvgNearEndLoss=None, BVlan=None, CVlan=None, CcmReceivedCount=None, CcmSentCount=None, CurrentFarEndLoss=None, CurrentFarEndLossRatio=None, CurrentNearEndLoss=None, CurrentNearEndLossRatio=None, DestinationMacAddress=None, LmmSentCount=None, MaxFarEndLoss=None, MaxFarEndLossRatio=None, MaxNearEndLoss=None, MaxNearEndLossRatio=None, MdLevel=None, MinFarEndLoss=None, MinFarEndLossRatio=None, MinNearEndLoss=None, MinNearEndLossRatio=None, NoReplyCount=None, SVlan=None, SourceMacAddress=None, SourceMepId=None):
        """Finds and retrieves periodicOamLmLearnedInfo resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve periodicOamLmLearnedInfo resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all periodicOamLmLearnedInfo resources from the server.

        Args
        ----
        - AvgFarEndLoss (str): 
        - AvgNearEndLoss (str): 
        - BVlan (str): 
        - CVlan (str): 
        - CcmReceivedCount (number): 
        - CcmSentCount (number): 
        - CurrentFarEndLoss (number): 
        - CurrentFarEndLossRatio (str): 
        - CurrentNearEndLoss (number): 
        - CurrentNearEndLossRatio (str): 
        - DestinationMacAddress (str): 
        - LmmSentCount (number): 
        - MaxFarEndLoss (number): 
        - MaxFarEndLossRatio (str): 
        - MaxNearEndLoss (number): 
        - MaxNearEndLossRatio (str): 
        - MdLevel (number): 
        - MinFarEndLoss (number): 
        - MinFarEndLossRatio (str): 
        - MinNearEndLoss (number): 
        - MinNearEndLossRatio (str): 
        - NoReplyCount (number): 
        - SVlan (str): 
        - SourceMacAddress (str): 
        - SourceMepId (number): 

        Returns
        -------
        - self: This instance with matching periodicOamLmLearnedInfo resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of periodicOamLmLearnedInfo data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the periodicOamLmLearnedInfo resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)

==> ixnetwork_restpy-1.0.59-py2.py3-none-any.whl: uhd_restpy/testplatform/sessions/ixnetwork/vport/protocols/periodicoamlmlearnedinfo_ee2b776d335186db7b509aa54dc286c1.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
from uhd_restpy.base import Base
from uhd_restpy.files import Files


class PeriodicOamLmLearnedInfo(Base):
    """NOT DEFINED
    The PeriodicOamLmLearnedInfo class encapsulates a list of periodicOamLmLearnedInfo resources that are managed by the system.
    A list of resources can be retrieved from the server using the PeriodicOamLmLearnedInfo.find() method.
    """

    __slots__ = ()
    _SDM_NAME = 'periodicOamLmLearnedInfo'
    _SDM_ATT_MAP = {
        'AvgFarEndLoss': 'avgFarEndLoss',
        'AvgNearEndLoss': 'avgNearEndLoss',
        'BVlan': 'bVlan',
        'CVlan': 'cVlan',
        'CcmReceivedCount': 'ccmReceivedCount',
        'CcmSentCount': 'ccmSentCount',
        'CurrentFarEndLoss': 'currentFarEndLoss',
        'CurrentFarEndLossRatio': 'currentFarEndLossRatio',
        'CurrentNearEndLoss': 'currentNearEndLoss',
        'CurrentNearEndLossRatio': 'currentNearEndLossRatio',
        'DestinationMacAddress': 'destinationMacAddress',
        'LmmSentCount': 'lmmSentCount',
        'MaxFarEndLoss': 'maxFarEndLoss',
        'MaxFarEndLossRatio': 'maxFarEndLossRatio',
        'MaxNearEndLoss': 'maxNearEndLoss',
        'MaxNearEndLossRatio': 'maxNearEndLossRatio',
        'MdLevel': 'mdLevel',
        'MinFarEndLoss': 'minFarEndLoss',
        'MinFarEndLossRatio': 'minFarEndLossRatio',
        'MinNearEndLoss': 'minNearEndLoss',
        'MinNearEndLossRatio': 'minNearEndLossRatio',
        'NoReplyCount': 'noReplyCount',
        'SVlan': 'sVlan',
        'SourceMacAddress': 'sourceMacAddress',
        'SourceMepId': 'sourceMepId',
    }

    def __init__(self, parent):
        super(PeriodicOamLmLearnedInfo, self).__init__(parent)

    @property
    def AvgFarEndLoss(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['AvgFarEndLoss'])

    @property
    def AvgNearEndLoss(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['AvgNearEndLoss'])

    @property
    def BVlan(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['BVlan'])

    @property
    def CVlan(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['CVlan'])

    @property
    def CcmReceivedCount(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['CcmReceivedCount'])

    @property
    def CcmSentCount(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['CcmSentCount'])

    @property
    def CurrentFarEndLoss(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentFarEndLoss'])

    @property
    def CurrentFarEndLossRatio(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentFarEndLossRatio'])

    @property
    def CurrentNearEndLoss(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentNearEndLoss'])

    @property
    def CurrentNearEndLossRatio(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['CurrentNearEndLossRatio'])

    @property
    def DestinationMacAddress(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['DestinationMacAddress'])

    @property
    def LmmSentCount(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['LmmSentCount'])

    @property
    def MaxFarEndLoss(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxFarEndLoss'])

    @property
    def MaxFarEndLossRatio(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxFarEndLossRatio'])

    @property
    def MaxNearEndLoss(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxNearEndLoss'])

    @property
    def MaxNearEndLossRatio(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxNearEndLossRatio'])

    @property
    def MdLevel(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MdLevel'])

    @property
    def MinFarEndLoss(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinFarEndLoss'])

    @property
    def MinFarEndLossRatio(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinFarEndLossRatio'])

    @property
    def MinNearEndLoss(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinNearEndLoss'])

    @property
    def MinNearEndLossRatio(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinNearEndLossRatio'])

    @property
    def NoReplyCount(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['NoReplyCount'])

    @property
    def SVlan(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['SVlan'])

    @property
    def SourceMacAddress(self):
        """
        Returns
        -------
        - str: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['SourceMacAddress'])

    @property
    def SourceMepId(self):
        """
        Returns
        -------
        - number: NOT DEFINED
        """
        return self._get_attribute(self._SDM_ATT_MAP['SourceMepId'])

    def find(self, AvgFarEndLoss=None, AvgNearEndLoss=None, BVlan=None, CVlan=None, CcmReceivedCount=None, CcmSentCount=None, CurrentFarEndLoss=None, CurrentFarEndLossRatio=None, CurrentNearEndLoss=None, CurrentNearEndLossRatio=None, DestinationMacAddress=None, LmmSentCount=None, MaxFarEndLoss=None, MaxFarEndLossRatio=None, MaxNearEndLoss=None, MaxNearEndLossRatio=None, MdLevel=None, MinFarEndLoss=None, MinFarEndLossRatio=None, MinNearEndLoss=None, MinNearEndLossRatio=None, NoReplyCount=None, SVlan=None, SourceMacAddress=None, SourceMepId=None):
        """Finds and retrieves periodicOamLmLearnedInfo resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve periodicOamLmLearnedInfo resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all periodicOamLmLearnedInfo resources from the server.

        Args
        ----
        - AvgFarEndLoss (str): NOT DEFINED
        - AvgNearEndLoss (str): NOT DEFINED
        - BVlan (str): NOT DEFINED
        - CVlan (str): NOT DEFINED
        - CcmReceivedCount (number): NOT DEFINED
        - CcmSentCount (number): NOT DEFINED
        - CurrentFarEndLoss (number): NOT DEFINED
        - CurrentFarEndLossRatio (str): NOT DEFINED
        - CurrentNearEndLoss (number): NOT DEFINED
        - CurrentNearEndLossRatio (str): NOT DEFINED
        - DestinationMacAddress (str): NOT DEFINED
        - LmmSentCount (number): NOT DEFINED
        - MaxFarEndLoss (number): NOT DEFINED
        - MaxFarEndLossRatio (str): NOT DEFINED
        - MaxNearEndLoss (number): NOT DEFINED
        - MaxNearEndLossRatio (str): NOT DEFINED
        - MdLevel (number): NOT DEFINED
        - MinFarEndLoss (number): NOT DEFINED
        - MinFarEndLossRatio (str): NOT DEFINED
        - MinNearEndLoss (number): NOT DEFINED
        - MinNearEndLossRatio (str): NOT DEFINED
        - NoReplyCount (number): NOT DEFINED
        - SVlan (str): NOT DEFINED
        - SourceMacAddress (str): NOT DEFINED
        - SourceMepId (number): NOT DEFINED

        Returns
        -------
        - self: This instance with matching periodicOamLmLearnedInfo resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of periodicOamLmLearnedInfo data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the periodicOamLmLearnedInfo resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)
